pub struct BlockCoord(pub Vec<usize>);Expand description
N-dimensional block coordinate.
Each element is an index into the corresponding QNIndex.blocks.
Ord is derived (lexicographic) to define a deterministic sort order
for Vec<BlockMeta>.
Tuple Fields
0: Vec<usize>Trait Implementations
Sourceimpl Clone for BlockCoord
impl Clone for BlockCoord
Sourcefn clone(&self) -> BlockCoord
fn clone(&self) -> BlockCoord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockCoord
impl Debug for BlockCoord
impl Eq for BlockCoord
Sourceimpl Hash for BlockCoord
impl Hash for BlockCoord
Sourceimpl Ord for BlockCoord
impl Ord for BlockCoord
Sourcefn cmp(&self, other: &BlockCoord) -> Ordering
fn cmp(&self, other: &BlockCoord) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BlockCoord
impl PartialEq for BlockCoord
Sourcefn eq(&self, other: &BlockCoord) -> bool
fn eq(&self, other: &BlockCoord) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BlockCoord
impl PartialOrd for BlockCoord
impl StructuralPartialEq for BlockCoord