#[repr(C)]pub struct Complex<T> {
pub re: T,
pub im: T,
}Expand description
A complex number in Cartesian form.
Representation and Foreign Function Interface Compatibility
Complex<T> is memory layout compatible with an array [T; 2].
Note that Complex<F> where F is a floating point type is only memory
layout compatible with C’s complex types, not necessarily calling
convention compatible. This means that for FFI you can only pass
Complex<F> behind a pointer, not as a value.
Examples
Example of extern function declaration.
use num_complex::Complex;
use std::os::raw::c_int;
extern "C" {
fn zaxpy_(n: *const c_int, alpha: *const Complex<f64>,
x: *const Complex<f64>, incx: *const c_int,
y: *mut Complex<f64>, incy: *const c_int);
}Fields
re: TReal portion of the complex number
im: TImaginary portion of the complex number
Implementations
Sourceimpl<T> Complex<T>
impl<T> Complex<T>
Sourceimpl<T> Complex<T>
impl<T> Complex<T>
Sourcepub fn l1_norm(&self) -> T
pub fn l1_norm(&self) -> T
Returns the L1 norm |re| + |im| – the Manhattan distance from the origin.
Sourceimpl<T> Complex<T>where
T: Float,
impl<T> Complex<T>where
T: Float,
Sourcepub fn cis(phase: T) -> Complex<T>
pub fn cis(phase: T) -> Complex<T>
Create a new Complex with a given phase: exp(i * phase).
See cis (mathematics).
Sourcepub fn to_polar(self) -> (T, T)
pub fn to_polar(self) -> (T, T)
Convert to polar form (r, theta), such that
self = r * exp(i * theta)
Sourcepub fn from_polar(r: T, theta: T) -> Complex<T>
pub fn from_polar(r: T, theta: T) -> Complex<T>
Convert a polar representation into a complex number.
Sourcepub fn exp(self) -> Complex<T>
pub fn exp(self) -> Complex<T>
Computes e^(self), where e is the base of the natural logarithm.
Sourcepub fn ln(self) -> Complex<T>
pub fn ln(self) -> Complex<T>
Computes the principal value of natural logarithm of self.
This function has one branch cut:
(-∞, 0], continuous from above.
The branch satisfies -π ≤ arg(ln(z)) ≤ π.
Sourcepub fn sqrt(self) -> Complex<T>
pub fn sqrt(self) -> Complex<T>
Computes the principal value of the square root of self.
This function has one branch cut:
(-∞, 0), continuous from above.
The branch satisfies -π/2 ≤ arg(sqrt(z)) ≤ π/2.
Sourcepub fn cbrt(self) -> Complex<T>
pub fn cbrt(self) -> Complex<T>
Computes the principal value of the cube root of self.
This function has one branch cut:
(-∞, 0), continuous from above.
The branch satisfies -π/3 ≤ arg(cbrt(z)) ≤ π/3.
Note that this does not match the usual result for the cube root of
negative real numbers. For example, the real cube root of -8 is -2,
but the principal complex cube root of -8 is 1 + i√3.
Sourcepub fn log(self, base: T) -> Complex<T>
pub fn log(self, base: T) -> Complex<T>
Returns the logarithm of self with respect to an arbitrary base.
Sourcepub fn expf(self, base: T) -> Complex<T>
pub fn expf(self, base: T) -> Complex<T>
Raises a floating point number to the complex power self.
Sourcepub fn asin(self) -> Complex<T>
pub fn asin(self) -> Complex<T>
Computes the principal value of the inverse sine of self.
This function has two branch cuts:
(-∞, -1), continuous from above.(1, ∞), continuous from below.
The branch satisfies -π/2 ≤ Re(asin(z)) ≤ π/2.
Sourcepub fn acos(self) -> Complex<T>
pub fn acos(self) -> Complex<T>
Computes the principal value of the inverse cosine of self.
This function has two branch cuts:
(-∞, -1), continuous from above.(1, ∞), continuous from below.
The branch satisfies 0 ≤ Re(acos(z)) ≤ π.
Sourcepub fn atan(self) -> Complex<T>
pub fn atan(self) -> Complex<T>
Computes the principal value of the inverse tangent of self.
This function has two branch cuts:
(-∞i, -i], continuous from the left.[i, ∞i), continuous from the right.
The branch satisfies -π/2 ≤ Re(atan(z)) ≤ π/2.
Sourcepub fn asinh(self) -> Complex<T>
pub fn asinh(self) -> Complex<T>
Computes the principal value of inverse hyperbolic sine of self.
This function has two branch cuts:
(-∞i, -i), continuous from the left.(i, ∞i), continuous from the right.
The branch satisfies -π/2 ≤ Im(asinh(z)) ≤ π/2.
Sourcepub fn acosh(self) -> Complex<T>
pub fn acosh(self) -> Complex<T>
Computes the principal value of inverse hyperbolic cosine of self.
This function has one branch cut:
(-∞, 1), continuous from above.
The branch satisfies -π ≤ Im(acosh(z)) ≤ π and 0 ≤ Re(acosh(z)) < ∞.
Sourcepub fn atanh(self) -> Complex<T>
pub fn atanh(self) -> Complex<T>
Computes the principal value of inverse hyperbolic tangent of self.
This function has two branch cuts:
(-∞, -1], continuous from above.[1, ∞), continuous from below.
The branch satisfies -π/2 ≤ Im(atanh(z)) ≤ π/2.
Sourcepub fn finv(self) -> Complex<T>
pub fn finv(self) -> Complex<T>
Returns 1/self using floating-point operations.
This may be more accurate than the generic self.inv() in cases
where self.norm_sqr() would overflow to ∞ or underflow to 0.
Examples
use num_complex::Complex64;
let c = Complex64::new(1e300, 1e300);
// The generic `inv()` will overflow.
assert!(!c.inv().is_normal());
// But we can do better for `Float` types.
let inv = c.finv();
assert!(inv.is_normal());
println!("{:e}", inv);
let expected = Complex64::new(5e-301, -5e-301);
assert!((inv - expected).norm() < 1e-315);Sourcepub fn fdiv(self, other: Complex<T>) -> Complex<T>
pub fn fdiv(self, other: Complex<T>) -> Complex<T>
Returns self/other using floating-point operations.
This may be more accurate than the generic Div implementation in cases
where other.norm_sqr() would overflow to ∞ or underflow to 0.
Examples
use num_complex::Complex64;
let a = Complex64::new(2.0, 3.0);
let b = Complex64::new(1e300, 1e300);
// Generic division will overflow.
assert!(!(a / b).is_normal());
// But we can do better for `Float` types.
let quotient = a.fdiv(b);
assert!(quotient.is_normal());
println!("{:e}", quotient);
let expected = Complex64::new(2.5e-300, 5e-301);
assert!((quotient - expected).norm() < 1e-315);Sourceimpl<T> Complex<T>where
T: Float + FloatConst,
impl<T> Complex<T>where
T: Float + FloatConst,